# sentiment-analysis

* feature: analyze the emotion of a text
* default model: distilbert-base-uncased-finetuned-sst-2-english
* precondition: none
* input: a paragraph of text
    * e.g.: "We are very happy to show you the �� Transformers library."
* output: text of this audio
    * e.g.: [{'label': 'POSITIVE', 'score': 0.9997795224189758}]

# Debug

* to debug or run your wrapper local, please implement .... todo

# for test